'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactUikitBase = require('react-uikit-base');

var _ufunc = require('ufunc');

var _reactUikitImg = require('react-uikit-img');

var _reactUikitImg2 = _interopRequireDefault(_reactUikitImg);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Overlay = function Overlay(props) {
  // CSS classes
  var captionCSS = {
    bottom: 'uk-overlay-bottom',
    left: 'uk-overlay-left',
    right: 'uk-overlay-right',
    top: 'uk-overlay-top'
  };

  var cssClassNames = _reactUikitBase.helpers.cleanClasses(['uk-overlay', props.image ? 'uk-overlay-hover' : null, props.classes]);

  var captionClassNames = _reactUikitBase.helpers.cleanClasses(['uk-overlay-panel', props.background ? 'uk-overlay-background' : null, props.icon ? 'uk-overlay-icon' : null, props.caption ? captionCSS[props.caption] : null]);

  // Remove non valid html attributes
  var ignoreProps = ['alt', 'background', 'flex', 'height', 'icon', 'image', 'large', 'medium', 'caption', 'small', 'src', 'width', 'xlarge'];

  var cleanProps = _reactUikitBase.helpers.cleanProps(ignoreProps)(props);

  // Elements
  var link = (0, _ufunc.maybeIf)(_react2.default.createElement('a', { className: 'uk-position-cover', href: '#' }), props.link);

  var img = _react2.default.createElement(_reactUikitImg2.default, {
    alt: props.alt,
    height: props.height,
    large: props.large,
    medium: props.medium,
    small: props.small,
    src: props.src,
    width: props.width,
    type: props.type,
    xlarge: props.xlarge,
    kitid: 'overlay-image-' + props.kitid,
    className: props.image ? 'uk-overlay-panel uk-overlay-image' : null
  });

  var figure = _react2.default.createElement(
    'figure',
    _extends({}, cleanProps, {
      className: cssClassNames,
      'data-kitid': 'overlay-' + props.kitid
    }),
    _react2.default.createElement(_reactUikitImg2.default, {
      alt: props.alt,
      height: props.height,
      large: props.large,
      medium: props.medium,
      small: props.small,
      src: props.image,
      width: props.width,
      type: props.type,
      xlarge: props.xlarge,
      kitid: 'overlay-background-image-' + props.kitid
    }),
    img,
    link
  );

  var caption = _react2.default.createElement(
    'figcaption',
    _extends({
      className: captionClassNames
    }, cleanProps, {
      'data-kitid': 'overlay-caption-' + props.kitid
    }),
    props.children
  );

  var linkCaption = _react2.default.createElement(
    'div',
    _extends({
      className: cssClassNames
    }, cleanProps, {
      'data-kitid': 'overlay-link-' + props.kitid
    }),
    props.children
  );

  var figureCaption = _react2.default.createElement(
    'figure',
    _extends({
      className: cssClassNames
    }, cleanProps, {
      'data-data-kitid': 'overlay-' + props.kitid
    }),
    img,
    (0, _ufunc.either)(linkCaption, caption)(props.link),
    link
  );

  // Return Component
  var component = (0, _ufunc.either)(figure, figureCaption);
  return component(props.image);
};

Overlay.propTypes = {
  alt: _react2.default.PropTypes.string,
  background: _react2.default.PropTypes.bool,
  flex: _react2.default.PropTypes.bool,
  height: _react2.default.PropTypes.string,
  icon: _react2.default.PropTypes.bool,
  image: _react2.default.PropTypes.string,
  large: _react2.default.PropTypes.object,
  medium: _react2.default.PropTypes.object,
  caption: _react2.default.PropTypes.string,
  small: _react2.default.PropTypes.object,
  src: _react2.default.PropTypes.string,
  width: _react2.default.PropTypes.string,
  xlarge: _react2.default.PropTypes.object
};

exports.default = (0, _reactUikitBase.base)(Overlay);